#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 configurator-pg
version:              0.2.11
visibility:           public
id:                   configurator-pg-0.2.11-Hj9o7WV67HdBmmUzOYW9bZ
key:                  configurator-pg-0.2.11-Hj9o7WV67HdBmmUzOYW9bZ
license:              BSD-3-Clause
copyright:
    Copyright 2011 MailRank, Inc.
    Copyright 2011-2014 Bryan O'\''Sullivan
    Copyright 2015-2016 Leon P Smith
    Copyright 2019-2022 Robert Vollmert

maintainer:           rob@vllmrt.net
author:               Robert Vollmert
homepage:             https://github.com/robx/configurator-pg
synopsis:             Reduced parser for configurator-ng config files
description:
    This module provides a simplified and updated interface to the
    configuration file format of
    <https://hackage.haskell.org/package/configurator configurator> and
    <https://hackage.haskell.org/package/configurator-ng configurator-ng>.
    Its aim is primarily to allow updating programs that depend on
    configurator-ng to new versions of GHC without changing the
    configuration file format.

category:             Configuration, Data
abi:                  1b5cda1195c2eb5706f357e3035df5a7
exposed:              True
exposed-modules:      Data.Configurator
hidden-modules:
    Data.Configurator.Load Data.Configurator.Parser
    Data.Configurator.Syntax Data.Configurator.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/configurator-pg-0.2.11
library-dirs:         /usr/lib/ghc-9.6.6/site-local/configurator-pg-0.2.11
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/configurator-pg-0.2.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-configurator-pg
hs-libraries:         HSconfigurator-pg-0.2.11-Hj9o7WV67HdBmmUzOYW9bZ
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    megaparsec-9.7.0-GFwpasy74KM76q3sEXYwuE
    protolude-0.3.5-Dz2WgUdqt2MKZr9Re6Dkeg
    scientific-0.3.8.1-5XoLLQPbco5H1OV8ua9Z5m text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-configurator-pg/html/configurator-pg.haddock

haddock-html:         /usr/share/doc/haskell-configurator-pg/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

